@@ -6,6 +6,7 @@ pub use self::config::Config;
 pub use self::dashboard::Dashboard;
 pub use self::input::Input;
 pub use self::message::Message;
+pub use self::mode::Mode;
 pub use self::palette::Palette;
 pub use self::pane::Pane;
 pub use self::server::Server;
@@ -23,6 +24,7 @@ pub mod history;
 pub mod input;
 pub mod log;
 pub mod message;
+pub mod mode;
 pub mod palette;
 pub mod pane;
 pub mod server;
