@@ -17,9 +17,7 @@ pub fn file() -> Result<fs::File, Error> {
 }
 
 fn path() -> Result<PathBuf, Error> {
-    let data_dir = environment::data_dir();
-
-    let parent = data_dir.join("halloy");
+    let parent = environment::data_dir();
 
     if !parent.exists() {
         fs::create_dir_all(&parent)?;
