@@ -30,25 +30,7 @@ pub enum Event {
 
 pub fn update(message: Message) -> Event {
     match message {
-        Message::Whois(user) => {
-            Event::SendWhois(user)
-            // let command = data::Command::Whois(None, user.nickname().to_string());
-
-            // let input = data::Input::command(buffer, command);
-
-            // if let Some(encoded) = input.encoded() {
-            //     clients.send(input.server(), encoded);
-            // }
-
-            // if let Some(message) = clients
-            //     .nickname(input.server())
-            //     .and_then(|nick| input.message(&nick))
-            // {
-            //     history.record_message(input.server(), message);
-            // }
-
-            // None
-        }
+        Message::Whois(user) => Event::SendWhois(user),
         Message::Query(user) => Event::OpenQuery(user),
     }
 }
@@ -56,15 +38,14 @@ pub fn update(message: Message) -> Event {
 pub fn view<'a>(content: impl Into<Element<'a, Message>>, user: User) -> Element<'a, Message> {
     let entries = Entry::list();
 
-    context_menu(content, entries, move |entry| {
+    context_menu(content, entries, move |entry, length| {
         let (content, message) = match entry {
             Entry::Whois => ("Whois", Message::Whois(user.clone())),
             Entry::Query => ("Message", Message::Query(user.clone())),
         };
 
         button(text(content).style(theme::Text::Primary))
-            // Based off longest entry text
-            .width(110)
+            .width(length)
             .style(theme::Button::Context)
             .on_press(message)
             .into()
