@@ -5,10 +5,10 @@ use std::time::{Duration, Instant};
 
 use data::history::manager::Broadcast;
 use data::user::Nick;
-use data::{dashboard, history, message, Config, Server, User};
+use data::{history, Config, Server, User};
 use iced::widget::pane_grid::{self, PaneGrid};
 use iced::widget::{container, row};
-use iced::{clipboard, window, Command, Length, Subscription};
+use iced::{clipboard, window, Command, Length};
 use pane::Pane;
 use side_menu::SideMenu;
 
@@ -32,7 +32,6 @@ pub enum Message {
     SelectedText(Vec<(f32, String)>),
     History(history::manager::Message),
     Close,
-    Tick(Instant),
     DashboardSaved(Result<(), data::dashboard::Error>),
     CloseHistory,
     QuitServer,
@@ -40,7 +39,7 @@ pub enum Message {
 
 impl Dashboard {
     pub fn empty(config: &Config) -> (Self, Command<Message>) {
-        let (panes, _) = pane_grid::State::new(Pane::new(Buffer::Empty, config.new_buffer.clone()));
+        let (panes, _) = pane_grid::State::new(Pane::new(Buffer::Empty, config));
 
         let mut dashboard = Dashboard {
             panes,
@@ -97,11 +96,9 @@ impl Dashboard {
                 }
                 pane::Message::SplitPane(axis) => {
                     if let Some(pane) = self.focus {
-                        let result = self.panes.split(
-                            axis,
-                            &pane,
-                            Pane::new(Buffer::Empty, config.new_buffer.clone()),
-                        );
+                        let result =
+                            self.panes
+                                .split(axis, &pane, Pane::new(Buffer::Empty, config));
                         self.last_changed = Some(Instant::now());
                         if let Some((pane, _)) = result {
                             return self.focus_pane(pane);
@@ -123,7 +120,7 @@ impl Dashboard {
                                         let input = data::Input::command(buffer, command);
 
                                         if let Some(encoded) = input.encoded() {
-                                            clients.send(input.server(), encoded);
+                                            clients.send(input.buffer(), encoded);
                                         }
 
                                         if let Some(message) = clients
@@ -245,10 +242,10 @@ impl Dashboard {
                             data::Buffer::Channel(server, channel) => {
                                 // Send part & close history file
                                 let command = data::Command::Part(channel.clone(), None);
-                                let input = data::Input::command(buffer, command);
+                                let input = data::Input::command(buffer.clone(), command);
 
                                 if let Some(encoded) = input.encoded() {
-                                    clients.send(&server, encoded);
+                                    clients.send(&buffer, encoded);
                                 }
 
                                 return self
@@ -286,7 +283,9 @@ impl Dashboard {
                         }
                     });
 
-                return clipboard::write(contents);
+                if !contents.is_empty() {
+                    return clipboard::write(contents);
+                }
             }
             Message::History(message) => {
                 self.history.update(message);
@@ -294,30 +293,6 @@ impl Dashboard {
             Message::Close => {
                 return window::close();
             }
-            Message::Tick(now) => {
-                let history = Command::batch(
-                    self.history
-                        .tick(now.into())
-                        .into_iter()
-                        .map(|task| Command::perform(task, Message::History))
-                        .collect::<Vec<_>>(),
-                );
-
-                if let Some(last_changed) = self.last_changed {
-                    if now.duration_since(last_changed) >= SAVE_AFTER {
-                        let dashboard = data::Dashboard::from(&*self);
-
-                        self.last_changed = None;
-
-                        return Command::batch(vec![
-                            Command::perform(dashboard.save(), Message::DashboardSaved),
-                            history,
-                        ]);
-                    }
-                }
-
-                return history;
-            }
             Message::DashboardSaved(Ok(_)) => {
                 log::info!("dashboard saved");
             }
@@ -334,14 +309,22 @@ impl Dashboard {
     pub fn view<'a>(
         &'a self,
         clients: &'a data::client::Map,
-        config: dashboard::Config,
+        config: &'a Config,
     ) -> Element<'a, Message> {
         let focus = self.focus;
 
         let pane_grid: Element<_> = PaneGrid::new(&self.panes, |id, pane, maximized| {
             let is_focused = focus == Some(id);
             let panes = self.panes.len();
-            pane.view(id, panes, is_focused, maximized, clients, &self.history)
+            pane.view(
+                id,
+                panes,
+                is_focused,
+                maximized,
+                clients,
+                &self.history,
+                config,
+            )
         })
         .on_click(pane::Message::PaneClicked)
         .on_resize(6, pane::Message::PaneResized)
@@ -361,7 +344,7 @@ impl Dashboard {
                 &self.history,
                 &self.panes,
                 self.focus,
-                config.sidebar_default_action,
+                config.dashboard.sidebar_default_action,
             )
             .map(Message::SideMenu);
 
@@ -453,9 +436,10 @@ impl Dashboard {
         if self.panes.len() == 1 {
             for (id, pane) in panes.iter() {
                 if let Buffer::Empty = &pane.buffer {
-                    self.panes.panes.entry(*id).and_modify(|p| {
-                        *p = Pane::new(Buffer::from(kind), config.new_buffer.clone())
-                    });
+                    self.panes
+                        .panes
+                        .entry(*id)
+                        .and_modify(|p| *p = Pane::new(Buffer::from(kind), config));
                     self.last_changed = Some(Instant::now());
 
                     return self.focus_pane(*id);
@@ -476,11 +460,9 @@ impl Dashboard {
             }
         };
 
-        let result = self.panes.split(
-            axis,
-            &pane_to_split,
-            Pane::new(Buffer::from(kind), config.new_buffer.clone()),
-        );
+        let result = self
+            .panes
+            .split(axis, &pane_to_split, Pane::new(Buffer::from(kind), config));
         self.last_changed = Some(Instant::now());
 
         if let Some((pane, _)) = result {
@@ -494,20 +476,6 @@ impl Dashboard {
         self.history.record_message(server, message);
     }
 
-    pub fn record_whois(&mut self, server: &Server, mut message: data::Message) {
-        // If a buffer for the server is focused, put the whois message there
-        message.source = self
-            .get_focused()
-            .and_then(|pane| {
-                pane.buffer.data().and_then(|buffer| {
-                    (buffer.server() == server).then(|| buffer.server_message_source())
-                })
-            })
-            .unwrap_or(message::Source::Server);
-
-        self.history.record_message(server, message);
-    }
-
     pub fn broadcast_quit(
         &mut self,
         server: &Server,
@@ -566,11 +534,6 @@ impl Dashboard {
             .broadcast(server, Broadcast::ConnectionFailed { error });
     }
 
-    fn get_focused(&mut self) -> Option<&Pane> {
-        let pane = self.focus?;
-        self.panes.get(&pane)
-    }
-
     fn get_focused_mut(&mut self) -> Option<(pane_grid::Pane, &mut Pane)> {
         let pane = self.focus?;
         self.panes.get_mut(&pane).map(|state| (pane, state))
@@ -626,8 +589,29 @@ impl Dashboard {
         )
     }
 
-    pub fn subscription(&self) -> Subscription<Message> {
-        iced::time::every(Duration::from_secs(1)).map(Message::Tick)
+    pub fn tick(&mut self, now: Instant) -> Command<Message> {
+        let history = Command::batch(
+            self.history
+                .tick(now.into())
+                .into_iter()
+                .map(|task| Command::perform(task, Message::History))
+                .collect::<Vec<_>>(),
+        );
+
+        if let Some(last_changed) = self.last_changed {
+            if now.duration_since(last_changed) >= SAVE_AFTER {
+                let dashboard = data::Dashboard::from(&*self);
+
+                self.last_changed = None;
+
+                return Command::batch(vec![
+                    Command::perform(dashboard.save(), Message::DashboardSaved),
+                    history,
+                ]);
+            }
+        }
+
+        history
     }
 }
 
@@ -647,11 +631,12 @@ impl From<data::Dashboard> for Dashboard {
                     b: Box::new(configuration(*b)),
                 },
                 data::Pane::Buffer { buffer, settings } => {
-                    Configuration::Pane(Pane::new(Buffer::from(buffer), settings))
-                }
-                data::Pane::Empty => {
-                    Configuration::Pane(Pane::new(Buffer::empty(), buffer::Settings::default()))
+                    Configuration::Pane(Pane::with_settings(Buffer::from(buffer), settings))
                 }
+                data::Pane::Empty => Configuration::Pane(Pane::with_settings(
+                    Buffer::empty(),
+                    buffer::Settings::default(),
+                )),
             }
         }
 
